@@ -414,13 +414,11 @@ class Daemon(object):
                     msg = _('Failed to remove supplemental groups')
                     LOG.critical(msg)
                     raise FailedToDropPrivileges(msg)
+                setgid(self.group)
 
             if self.user is not None:
                 setuid(self.user)
 
-            if self.group is not None:
-                setgid(self.group)
-
         finally:
             capabilities.set_keepcaps(False)
 
@@ -551,7 +549,14 @@ def helper_main():
     logging.register_options(cfg.CONF)
 
     cfg.CONF(args=sys.argv[1:], project='privsep')
-    logging.setup(cfg.CONF, 'privsep')  # note replace_logging call below
+    # note replace_logging call below
+    try:
+        logging.setup(cfg.CONF, 'privsep', fix_eventlet=False)
+    except TypeError:
+        # NOTE(ralonsoh): in case of using oslo.log<5.0.2, kwarg
+        # "fix_eventlet" won't be defined. Remove this try clause when oslo.log
+        # is bumped.
+        logging.setup(cfg.CONF, 'privsep')
 
     context = importutils.import_class(cfg.CONF.privsep_context)
     from oslo_privsep import priv_context   # Avoid circular import
